@@ -10,6 +10,11 @@ from sys import float_info
 class StaticUtils:
    __SYSTEM = system()
    
+   @staticmethod
+   def assertInheritance(o, t, name = None):
+      if not isinstance(o, t):
+         raise ValueError("{} must be a subclass of {}".format(f"'{name}'" if name else type(o), t))
+   
    @staticmethod
    def findKeyInDictionary(dictionary, key):
       result = []
